@@ -4,6 +4,6 @@ print.loopsummary <- function (x,...) {
   cat("Call for Original Fit:\n")
   print(x$call)
     cat("\nBootstrapped Estimates:\n")
-    print(x$values[-c(1,2),c("Boot.Estimate","Bias","Std.Error","B.q0.025","B.q0.975")],digits=4)
+    print(x$values[,c("Boot.Estimate","Bias","Std.Error","B.q0.025","B.q0.975")],digits=4)
  
 }
